An analysis of the renormalization group method for asymptotic expansions with logarithmic switchback terms
Author: Matt Holzer
Description: Advances in Differential Equations
Keywords: 34C20; 34E05; 34E15; 37G05; 70K45
Date: 2014-03-01

Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
Please wait...
No Project Euclid account? Create an account
or Sign in with your institutional credentials

We can help you reset your password using the email address linked to your Project Euclid account.

Email
Registered users receive a variety of benefits including the ability to customize email alerts, create favorite journals list, and save searches. Please note that a Project Euclid web account does not automatically grant access to full-text content. An institutional or society member subscription is required to view non-Open Access content. Contact customer_support@projecteuclid.org with any questions.
View Project Euclid Privacy Policy
All Fields are Required
* First Name
* Last/Family Name
* Email
* Password
Password Requirements: Minimum 8 characters, must include as least one uppercase, one lowercase letter, and one number or permitted symbol Valid Symbols for password:
~ Tilde
! Exclamation Mark
@ At sign
$ Dollar sign
^ Caret
( Opening Parenthesis
) Closing Parenthesis
_ Underscore
. Period
* Confirm Password
Please wait...
Web Account created successfully
March/April 2014 An analysis of the renormalization group method for asymptotic expansions with logarithmic switchback terms
Matt Holzer, Tasso J. Kaper
Adv. Differential Equations 19(3/4): 245-282 (March/April 2014). DOI: 10.57262/ade/1391109086
PERSONAL SIGN IN
Full access may be available with your subscription
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
or Sign in with your institutional credentials
PURCHASE SINGLE ARTICLE
This article is only available to subscribers. It is not available for individual sale.
This will count as one of your downloads.
You will have access to both the presentation and article (if available).
This content is available for download via your institution's subscription. To access this item, please sign in to your personal account.
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
My Library
You currently do not have any folders to save your paper to! Create a new folder below.

## Abstract

The renormalization group method of Chen, Goldenfeld, and Oono offers a comprehensive approach to formally computing asymptotic expansions of the solutions to singular perturbation problems and multi-scale problems. In particular, the RG method applies to a broad array of problems customarily treated with disparate methods, such as the method of multiple scales, boundary layer theory, matched asymptotic expansions, Poincare-Lindstedt theory, the WKBJ method with and without turning points, the method of averaging, and others. For problems in which the expansions are in powers of the small parameter, it has been shown that the RG method leads to uniformly valid asymptotic expansions of the solutions. In addition, it has been shown that the RG condition constitutes an invariance condition, that the RG method is effectively a resummation technique, and that it is equivalent to normal form theory for certain broad classes of perturbed ordinary differential equations. However, there has not yet been an analysis of the validity of the RG method, i.e.,i> a demonstration that it leads to uniformly valid asymptotic expansions, for problems in which the expansions also involve logarithms of the small parameter as gauge functions. The aim of this article is to provide this justification of the RG method. In particular, we extend the approach developed in DeVille, et ali>. Physica D 237 no. 8, 1029 {-}1052] from the classes of autonomous and non-autonomous perturbations considered there to include the non-autonomous systems subject to singular perturbations for which the solutions involve logarithmic gauge functions. This framework is built upon the relationship between the RG method and normal form theory. We apply the RG method to three successively-more complex examples and also elucidate the common general features.

## Citation

Download Citation

Matt Holzer. Tasso J. Kaper. "An analysis of the renormalization group method for asymptotic expansions with logarithmic switchback terms." Adv. Differential Equations 19 (3/4) 245 - 282, March/April 2014. https://doi.org/10.57262/ade/1391109086

## Information

Published: March/April 2014
First available in Project Euclid: 30 January 2014

zbMATH: 1292.34051
MathSciNet: MR3161662
Digital Object Identifier: 10.57262/ade/1391109086

Subjects:
Primary: 34C20 , 34E05 , 34E15 , 37G05 , 70K45

Rights: Copyright © 2014 Khayyam Publishing, Inc.
ACCESS THE FULL ARTICLE
PERSONAL SIGN IN
Full access may be available with your subscription
Email
Password Forgot your password?
Show
Remember Email on this computer
Remember Password
No Project Euclid account? Create an account
or Sign in with your institutional credentials
PURCHASE THIS CONTENT
PURCHASE SINGLE ARTICLE
This article is only available to subscribers.
It is not available for individual sale.
JOURNAL ARTICLE
38 PAGES

DOWNLOAD PDF + SAVE TO MY LIBRARY

GET CITATION
My Library
You currently do not have any folders to save your paper to! Create a new folder below.
Folder Name
Folder Description
< Previous Article
|
Next Article >
Adv. Differential Equations
Vol.19 • No. 3/4 • March/April 2014
Khayyam Publishing, Inc.
Subscribe to Project Euclid
Receive erratum alerts for this article
Matt Holzer, Tasso J. Kaper "An analysis of the renormalization group method for asymptotic expansions with logarithmic switchback terms," Advances in Differential Equations, Adv. Differential Equations 19(3/4), 245-282, (March/April 2014)
Include:
Citation Only
Citation & Abstract
Format:
RIS
EndNote
BibTex
Print Friendly Version (PDF)

## KEYWORDS/PHRASES

Keywords
in
Remove
in
Remove
in
Remove
+ Add another field

## PUBLICATION TITLE:

All Titles
Choose Title(s)

## PUBLICATION YEARS

Range
Single Year

Clear Form